{% extends "components/base.html" %}

{% block title_tag %}
{{ config.SITE_NAME }}
{% endblock title_tag %}

{% block meta %}
<meta property="og:title" content="{{ config.SITE_NAME }}">
<meta property="og:type" content="website">
<meta property="og:image" content="{{ config.SITE_URL }}{{ '/android-chrome-256x256.png' | autoversion }}">
<link rel="canonical" href="{{ config.SITE_URL }}/">
{% endblock meta %}

{% block content %}
<div class="posts">
    {% for post in posts %}
    <article class="post">
        <header>
            <h2 class="post-title">
                <a href="/posts/{{ post.slug }}/">{{ post.title }}</a>
            </h2>
            <span class="post-date">
                <small>
                    <a href="/categories/{{ post.category.slug }}/">{{ post.category.name }}</a> -
                    <time datetime="{{ post.date }}">{{ post.date.strftime('%a, %b %d, %Y') }}</time>
                </small>
            </span>
        </header>
        <div class="article-content">
            {{ post.excerpt }}
            <small><a href="/posts/{{ post.slug }}/">Read More...</a></small>
        </div>
    </article>
    {% endfor %}
</div>
{% endblock content %}