{% extends "components/base.html" %}

{% block content %}
<h1 class="post-title">Page not found</h1>
<p class="lead">
    Sorry, we've misplaced that URL or it's pointing to something that doesn't exist.
    <a href="/">Head back home</a> to try finding it again.
</p>
{% endblock content %}