<script async src="https://www.googletagmanager.com/gtag/js?id={{ config.GTAG_ID }}"></script>
<script>
    window.dataLayer = window.dataLayer || [];
    function gtag() { dataLayer.push(arguments); }
    gtag('js', new Date());

    gtag('config', '{{ config.GTAG_ID }}', { 'anonymize_ip': true });
</script>